@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.recommender_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -71,7 +83,7 @@ class RecommenderClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RecommenderTransport]:
         """Returns an appropriate transport class.
 
@@ -467,8 +479,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RecommenderTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RecommenderTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the recommender client.
@@ -482,7 +494,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
             transport (Union[str, RecommenderTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -512,6 +524,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -564,11 +577,11 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def list_insights(
         self,
-        request: Union[recommender_service.ListInsightsRequest, dict] = None,
+        request: Optional[Union[recommender_service.ListInsightsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInsightsPager:
         r"""Lists insights for the specified Cloud Resource. Requires the
@@ -695,11 +708,11 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def get_insight(
         self,
-        request: Union[recommender_service.GetInsightRequest, dict] = None,
+        request: Optional[Union[recommender_service.GetInsightRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> insight.Insight:
         r"""Gets the requested insight. Requires the recommender.*.get IAM
@@ -797,13 +810,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def mark_insight_accepted(
         self,
-        request: Union[recommender_service.MarkInsightAcceptedRequest, dict] = None,
+        request: Optional[
+            Union[recommender_service.MarkInsightAcceptedRequest, dict]
+        ] = None,
         *,
-        name: str = None,
-        state_metadata: Mapping[str, str] = None,
-        etag: str = None,
+        name: Optional[str] = None,
+        state_metadata: Optional[MutableMapping[str, str]] = None,
+        etag: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> insight.Insight:
         r"""Marks the Insight State as Accepted. Users can use this method
@@ -851,7 +866,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Mapping[str, str]):
+            state_metadata (MutableMapping[str, str]):
                 Optional. State properties user wish to include with
                 this state. Full replace of the current state_metadata.
 
@@ -927,12 +942,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def list_recommendations(
         self,
-        request: Union[recommender_service.ListRecommendationsRequest, dict] = None,
+        request: Optional[
+            Union[recommender_service.ListRecommendationsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListRecommendationsPager:
         r"""Lists recommendations for the specified Cloud Resource. Requires
@@ -1087,11 +1104,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def get_recommendation(
         self,
-        request: Union[recommender_service.GetRecommendationRequest, dict] = None,
+        request: Optional[
+            Union[recommender_service.GetRecommendationRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> recommendation.Recommendation:
         r"""Gets the requested recommendation. Requires the
@@ -1190,15 +1209,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def mark_recommendation_claimed(
         self,
-        request: Union[
-            recommender_service.MarkRecommendationClaimedRequest, dict
+        request: Optional[
+            Union[recommender_service.MarkRecommendationClaimedRequest, dict]
         ] = None,
         *,
-        name: str = None,
-        state_metadata: Mapping[str, str] = None,
-        etag: str = None,
+        name: Optional[str] = None,
+        state_metadata: Optional[MutableMapping[str, str]] = None,
+        etag: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> recommendation.Recommendation:
         r"""Marks the Recommendation State as Claimed. Users can use this
@@ -1249,7 +1268,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Mapping[str, str]):
+            state_metadata (MutableMapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1332,15 +1351,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def mark_recommendation_succeeded(
         self,
-        request: Union[
-            recommender_service.MarkRecommendationSucceededRequest, dict
+        request: Optional[
+            Union[recommender_service.MarkRecommendationSucceededRequest, dict]
         ] = None,
         *,
-        name: str = None,
-        state_metadata: Mapping[str, str] = None,
-        etag: str = None,
+        name: Optional[str] = None,
+        state_metadata: Optional[MutableMapping[str, str]] = None,
+        etag: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> recommendation.Recommendation:
         r"""Marks the Recommendation State as Succeeded. Users can use this
@@ -1391,7 +1410,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Mapping[str, str]):
+            state_metadata (MutableMapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1474,15 +1493,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def mark_recommendation_failed(
         self,
-        request: Union[
-            recommender_service.MarkRecommendationFailedRequest, dict
+        request: Optional[
+            Union[recommender_service.MarkRecommendationFailedRequest, dict]
         ] = None,
         *,
-        name: str = None,
-        state_metadata: Mapping[str, str] = None,
-        etag: str = None,
+        name: Optional[str] = None,
+        state_metadata: Optional[MutableMapping[str, str]] = None,
+        etag: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> recommendation.Recommendation:
         r"""Marks the Recommendation State as Failed. Users can use this
@@ -1533,7 +1552,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Mapping[str, str]):
+            state_metadata (MutableMapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1614,11 +1633,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def get_recommender_config(
         self,
-        request: Union[recommender_service.GetRecommenderConfigRequest, dict] = None,
+        request: Optional[
+            Union[recommender_service.GetRecommenderConfigRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> recommender_config.RecommenderConfig:
         r"""Gets the requested Recommender Config. There is only
@@ -1722,12 +1743,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def update_recommender_config(
         self,
-        request: Union[recommender_service.UpdateRecommenderConfigRequest, dict] = None,
+        request: Optional[
+            Union[recommender_service.UpdateRecommenderConfigRequest, dict]
+        ] = None,
         *,
-        recommender_config: gcr_recommender_config.RecommenderConfig = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        recommender_config: Optional[gcr_recommender_config.RecommenderConfig] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcr_recommender_config.RecommenderConfig:
         r"""Updates a Recommender Config. This will create a new
@@ -1834,11 +1857,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def get_insight_type_config(
         self,
-        request: Union[recommender_service.GetInsightTypeConfigRequest, dict] = None,
+        request: Optional[
+            Union[recommender_service.GetInsightTypeConfigRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> insight_type_config.InsightTypeConfig:
         r"""Gets the requested InsightTypeConfig. There is only
@@ -1942,12 +1967,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     def update_insight_type_config(
         self,
-        request: Union[recommender_service.UpdateInsightTypeConfigRequest, dict] = None,
+        request: Optional[
+            Union[recommender_service.UpdateInsightTypeConfigRequest, dict]
+        ] = None,
         *,
-        insight_type_config: gcr_insight_type_config.InsightTypeConfig = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        insight_type_config: Optional[gcr_insight_type_config.InsightTypeConfig] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcr_insight_type_config.InsightTypeConfig:
         r"""Updates an InsightTypeConfig change. This will create
@@ -2066,14 +2093,9 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-recommender",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RecommenderClient",)
